@@ -40,7 +40,6 @@
 //	NOTE:  Use of 'LOG_FAIL' allows the fail messages to appear in the log without
 //	all of the standard logging associated with a DEBUG build (i.e. hopefully failures only).
 #define	LOG_FAIL
-#define kAUDIO_DEBUGIOLOG_TO_KPRINTF		0
 
 #ifdef DEBUG
 	#ifndef LOG_FAIL
@@ -49,7 +48,7 @@
 #endif
 
 #ifdef DEBUGLOG
-#if kAUDIO_DEBUGIOLOG_TO_KPRINTF
+#ifdef DEBUGLOG_TO_KPRINTF
 	#define debugIOLog( level, message... ) \
 		do { kprintf ( message ); kprintf ( "\n" ); } while (0)
 #else
